package sexps-rewriter

  1. Overview
  2. Docs

Module Sexps_rewriter.Visitor_decisionSource

While we visit the sexps from the original file, we may decide what to do at each step of the iteration:

  • Do we want to stop the execution there?
  • Or do we want to recurse with the children of the current sexp
  • Or simply go to the next one sexp in the queue?
Sourcetype t =
  1. | Break
    (*

    Stops the current execution of visit.

    *)
  2. | Continue
    (*

    Recurse and visit the children of the current sexp if any, or continue with the next sexp in the queue.

    *)
  3. | Skip
    (*

    Do not drill in, skip the current sexp and continue with the next sexp in the queue. If the current sexp is an atom, this is equivalent to Continue, which should be preferred by default.

    *)